Class: Aws::OpenSearchServerless::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::OpenSearchServerless::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-opensearchserverless/client.rb,
sig/client.rbs
Overview
An API client for OpenSearchServerless. To construct a client, you need to configure a :region and :credentials.
client = Aws::OpenSearchServerless::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetCollectionGroupResponseSuccess, _BatchGetCollectionResponseSuccess, _BatchGetEffectiveLifecyclePolicyResponseSuccess, _BatchGetLifecyclePolicyResponseSuccess, _BatchGetVpcEndpointResponseSuccess, _CreateAccessPolicyResponseSuccess, _CreateCollectionGroupResponseSuccess, _CreateCollectionResponseSuccess, _CreateIndexResponseSuccess, _CreateLifecyclePolicyResponseSuccess, _CreateSecurityConfigResponseSuccess, _CreateSecurityPolicyResponseSuccess, _CreateVpcEndpointResponseSuccess, _DeleteAccessPolicyResponseSuccess, _DeleteCollectionGroupResponseSuccess, _DeleteCollectionResponseSuccess, _DeleteIndexResponseSuccess, _DeleteLifecyclePolicyResponseSuccess, _DeleteSecurityConfigResponseSuccess, _DeleteSecurityPolicyResponseSuccess, _DeleteVpcEndpointResponseSuccess, _GetAccessPolicyResponseSuccess, _GetAccountSettingsResponseSuccess, _GetIndexResponseSuccess, _GetPoliciesStatsResponseSuccess, _GetSecurityConfigResponseSuccess, _GetSecurityPolicyResponseSuccess, _ListAccessPoliciesResponseSuccess, _ListCollectionGroupsResponseSuccess, _ListCollectionsResponseSuccess, _ListLifecyclePoliciesResponseSuccess, _ListSecurityConfigsResponseSuccess, _ListSecurityPoliciesResponseSuccess, _ListTagsForResourceResponseSuccess, _ListVpcEndpointsResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAccessPolicyResponseSuccess, _UpdateAccountSettingsResponseSuccess, _UpdateCollectionGroupResponseSuccess, _UpdateCollectionResponseSuccess, _UpdateIndexResponseSuccess, _UpdateLifecyclePolicyResponseSuccess, _UpdateSecurityConfigResponseSuccess, _UpdateSecurityPolicyResponseSuccess, _UpdateVpcEndpointResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_collection(params = {}) ⇒ Types::BatchGetCollectionResponse
Returns attributes for one or more collections, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints.
-
#batch_get_collection_group(params = {}) ⇒ Types::BatchGetCollectionGroupResponse
Returns attributes for one or more collection groups, including capacity limits and the number of collections in each group.
-
#batch_get_effective_lifecycle_policy(params = {}) ⇒ Types::BatchGetEffectiveLifecyclePolicyResponse
Returns a list of successful and failed retrievals for the OpenSearch Serverless indexes.
-
#batch_get_lifecycle_policy(params = {}) ⇒ Types::BatchGetLifecyclePolicyResponse
Returns one or more configured OpenSearch Serverless lifecycle policies.
-
#batch_get_vpc_endpoint(params = {}) ⇒ Types::BatchGetVpcEndpointResponse
Returns attributes for one or more VPC endpoints associated with the current account.
-
#create_access_policy(params = {}) ⇒ Types::CreateAccessPolicyResponse
Creates a data access policy for OpenSearch Serverless.
-
#create_collection(params = {}) ⇒ Types::CreateCollectionResponse
Creates a new OpenSearch Serverless collection.
-
#create_collection_group(params = {}) ⇒ Types::CreateCollectionGroupResponse
Creates a collection group within OpenSearch Serverless.
-
#create_index(params = {}) ⇒ Struct
Creates an index within an OpenSearch Serverless collection.
-
#create_lifecycle_policy(params = {}) ⇒ Types::CreateLifecyclePolicyResponse
Creates a lifecyle policy to be applied to OpenSearch Serverless indexes.
-
#create_security_config(params = {}) ⇒ Types::CreateSecurityConfigResponse
Specifies a security configuration for OpenSearch Serverless.
-
#create_security_policy(params = {}) ⇒ Types::CreateSecurityPolicyResponse
Creates a security policy to be used by one or more OpenSearch Serverless collections.
-
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an OpenSearch Serverless-managed interface VPC endpoint.
-
#delete_access_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless access policy.
-
#delete_collection(params = {}) ⇒ Types::DeleteCollectionResponse
Deletes an OpenSearch Serverless collection.
-
#delete_collection_group(params = {}) ⇒ Struct
Deletes a collection group.
-
#delete_index(params = {}) ⇒ Struct
Deletes an index from an OpenSearch Serverless collection.
-
#delete_lifecycle_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless lifecycle policy.
-
#delete_security_config(params = {}) ⇒ Struct
Deletes a security configuration for OpenSearch Serverless.
-
#delete_security_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless security policy.
-
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an OpenSearch Serverless-managed interface endpoint.
-
#get_access_policy(params = {}) ⇒ Types::GetAccessPolicyResponse
Returns an OpenSearch Serverless access policy.
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Returns account-level settings related to OpenSearch Serverless.
-
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an index in an OpenSearch Serverless collection, including its schema definition.
-
#get_policies_stats(params = {}) ⇒ Types::GetPoliciesStatsResponse
Returns statistical information about your OpenSearch Serverless access policies, security configurations, and security policies.
-
#get_security_config(params = {}) ⇒ Types::GetSecurityConfigResponse
Returns information about an OpenSearch Serverless security configuration.
-
#get_security_policy(params = {}) ⇒ Types::GetSecurityPolicyResponse
Returns information about a configured OpenSearch Serverless security policy.
-
#list_access_policies(params = {}) ⇒ Types::ListAccessPoliciesResponse
Returns information about a list of OpenSearch Serverless access policies.
-
#list_collection_groups(params = {}) ⇒ Types::ListCollectionGroupsResponse
Returns a list of collection groups.
-
#list_collections(params = {}) ⇒ Types::ListCollectionsResponse
Lists all OpenSearch Serverless collections.
-
#list_lifecycle_policies(params = {}) ⇒ Types::ListLifecyclePoliciesResponse
Returns a list of OpenSearch Serverless lifecycle policies.
-
#list_security_configs(params = {}) ⇒ Types::ListSecurityConfigsResponse
Returns information about configured OpenSearch Serverless security configurations.
-
#list_security_policies(params = {}) ⇒ Types::ListSecurityPoliciesResponse
Returns information about configured OpenSearch Serverless security policies.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the tags for an OpenSearch Serverless resource.
-
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Returns the OpenSearch Serverless-managed interface VPC endpoints associated with the current account.
-
#tag_resource(params = {}) ⇒ Struct
Associates tags with an OpenSearch Serverless resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or set of tags from an OpenSearch Serverless resource.
-
#update_access_policy(params = {}) ⇒ Types::UpdateAccessPolicyResponse
Updates an OpenSearch Serverless access policy.
-
#update_account_settings(params = {}) ⇒ Types::UpdateAccountSettingsResponse
Update the OpenSearch Serverless settings for the current Amazon Web Services account.
-
#update_collection(params = {}) ⇒ Types::UpdateCollectionResponse
Updates an OpenSearch Serverless collection.
-
#update_collection_group(params = {}) ⇒ Types::UpdateCollectionGroupResponse
Updates the description and capacity limits of a collection group.
-
#update_index(params = {}) ⇒ Struct
Updates an existing index in an OpenSearch Serverless collection.
-
#update_lifecycle_policy(params = {}) ⇒ Types::UpdateLifecyclePolicyResponse
Updates an OpenSearch Serverless access policy.
-
#update_security_config(params = {}) ⇒ Types::UpdateSecurityConfigResponse
Updates a security configuration for OpenSearch Serverless.
-
#update_security_policy(params = {}) ⇒ Types::UpdateSecurityPolicyResponse
Updates an OpenSearch Serverless security policy.
-
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Updates an OpenSearch Serverless-managed interface endpoint.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3017 3018 3019 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 3017 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3020 3021 3022 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 3020 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_collection(params = {}) ⇒ Types::BatchGetCollectionResponse
Returns attributes for one or more collections, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
88 |
# File 'sig/client.rbs', line 88
def batch_get_collection: (
|
#batch_get_collection_group(params = {}) ⇒ Types::BatchGetCollectionGroupResponse
Returns attributes for one or more collection groups, including capacity limits and the number of collections in each group. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
100 |
# File 'sig/client.rbs', line 100
def batch_get_collection_group: (
|
#batch_get_effective_lifecycle_policy(params = {}) ⇒ Types::BatchGetEffectiveLifecyclePolicyResponse
Returns a list of successful and failed retrievals for the OpenSearch Serverless indexes. For more information, see Viewing data lifecycle policies.
112 |
# File 'sig/client.rbs', line 112
def batch_get_effective_lifecycle_policy: (
|
#batch_get_lifecycle_policy(params = {}) ⇒ Types::BatchGetLifecyclePolicyResponse
Returns one or more configured OpenSearch Serverless lifecycle policies. For more information, see Viewing data lifecycle policies.
128 |
# File 'sig/client.rbs', line 128
def batch_get_lifecycle_policy: (
|
#batch_get_vpc_endpoint(params = {}) ⇒ Types::BatchGetVpcEndpointResponse
Returns attributes for one or more VPC endpoints associated with the current account. For more information, see Access Amazon OpenSearch Serverless using an interface endpoint.
144 |
# File 'sig/client.rbs', line 144
def batch_get_vpc_endpoint: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2990 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::OpenSearchServerless') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-opensearchserverless' context[:gem_version] = '1.62.0' Seahorse::Client::Request.new(handlers, context) end |
#create_access_policy(params = {}) ⇒ Types::CreateAccessPolicyResponse
Creates a data access policy for OpenSearch Serverless. Access policies limit access to collections and the resources within them, and allow a user to access that data irrespective of the access mechanism or network source. For more information, see Data access control for Amazon OpenSearch Serverless.
154 |
# File 'sig/client.rbs', line 154
def create_access_policy: (
|
#create_collection(params = {}) ⇒ Types::CreateCollectionResponse
Creates a new OpenSearch Serverless collection. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
168 |
# File 'sig/client.rbs', line 168
def create_collection: (
|
#create_collection_group(params = {}) ⇒ Types::CreateCollectionGroupResponse
Creates a collection group within OpenSearch Serverless. Collection groups let you manage OpenSearch Compute Units (OCUs) at a group level, with multiple collections sharing the group's capacity limits.
For more information, see Managing collection groups.
197 |
# File 'sig/client.rbs', line 197
def create_collection_group: (
|
#create_index(params = {}) ⇒ Struct
Creates an index within an OpenSearch Serverless collection. Unlike other OpenSearch indexes, indexes created by this API are automatically configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment in the OpenSearch User Guide.
222 |
# File 'sig/client.rbs', line 222
def create_index: (
|
#create_lifecycle_policy(params = {}) ⇒ Types::CreateLifecyclePolicyResponse
Creates a lifecyle policy to be applied to OpenSearch Serverless indexes. Lifecycle policies define the number of days or hours to retain the data on an OpenSearch Serverless index. For more information, see Creating data lifecycle policies.
235 |
# File 'sig/client.rbs', line 235
def create_lifecycle_policy: (
|
#create_security_config(params = {}) ⇒ Types::CreateSecurityConfigResponse
Specifies a security configuration for OpenSearch Serverless. For more information, see SAML authentication for Amazon OpenSearch Serverless.
249 |
# File 'sig/client.rbs', line 249
def create_security_config: (
|
#create_security_policy(params = {}) ⇒ Types::CreateSecurityPolicyResponse
Creates a security policy to be used by one or more OpenSearch Serverless collections. Security policies provide access to a collection and its OpenSearch Dashboards endpoint from public networks or specific VPC endpoints. They also allow you to secure a collection with a KMS encryption key. For more information, see Network access for Amazon OpenSearch Serverless and Encryption at rest for Amazon OpenSearch Serverless.
278 |
# File 'sig/client.rbs', line 278
def create_security_policy: (
|
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an OpenSearch Serverless-managed interface VPC endpoint. For more information, see Access Amazon OpenSearch Serverless using an interface endpoint.
292 |
# File 'sig/client.rbs', line 292
def create_vpc_endpoint: (
|
#delete_access_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless access policy. For more information, see Data access control for Amazon OpenSearch Serverless.
305 |
# File 'sig/client.rbs', line 305
def delete_access_policy: (
|
#delete_collection(params = {}) ⇒ Types::DeleteCollectionResponse
Deletes an OpenSearch Serverless collection. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
317 |
# File 'sig/client.rbs', line 317
def delete_collection: (
|
#delete_collection_group(params = {}) ⇒ Struct
Deletes a collection group. You can only delete empty collection groups that contain no collections. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
327 |
# File 'sig/client.rbs', line 327
def delete_collection_group: (
|
#delete_index(params = {}) ⇒ Struct
Deletes an index from an OpenSearch Serverless collection. Be aware that the index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.
337 |
# File 'sig/client.rbs', line 337
def delete_index: (
|
#delete_lifecycle_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless lifecycle policy. For more information, see Deleting data lifecycle policies.
347 |
# File 'sig/client.rbs', line 347
def delete_lifecycle_policy: (
|
#delete_security_config(params = {}) ⇒ Struct
Deletes a security configuration for OpenSearch Serverless. For more information, see SAML authentication for Amazon OpenSearch Serverless.
358 |
# File 'sig/client.rbs', line 358
def delete_security_config: (
|
#delete_security_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless security policy.
368 |
# File 'sig/client.rbs', line 368
def delete_security_policy: (
|
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an OpenSearch Serverless-managed interface endpoint. For more information, see Access Amazon OpenSearch Serverless using an interface endpoint.
380 |
# File 'sig/client.rbs', line 380
def delete_vpc_endpoint: (
|
#get_access_policy(params = {}) ⇒ Types::GetAccessPolicyResponse
Returns an OpenSearch Serverless access policy. For more information, see Data access control for Amazon OpenSearch Serverless.
391 |
# File 'sig/client.rbs', line 391
def get_access_policy: (
|
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Returns account-level settings related to OpenSearch Serverless.
402 |
# File 'sig/client.rbs', line 402
def get_account_settings: (
|
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an index in an OpenSearch Serverless collection, including its schema definition. The index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.
411 |
# File 'sig/client.rbs', line 411
def get_index: (
|
#get_policies_stats(params = {}) ⇒ Types::GetPoliciesStatsResponse
Returns statistical information about your OpenSearch Serverless access policies, security configurations, and security policies.
426 |
# File 'sig/client.rbs', line 426
def get_policies_stats: (
|
#get_security_config(params = {}) ⇒ Types::GetSecurityConfigResponse
Returns information about an OpenSearch Serverless security configuration. For more information, see SAML authentication for Amazon OpenSearch Serverless.
435 |
# File 'sig/client.rbs', line 435
def get_security_config: (
|
#get_security_policy(params = {}) ⇒ Types::GetSecurityPolicyResponse
Returns information about a configured OpenSearch Serverless security policy. For more information, see Network access for Amazon OpenSearch Serverless and Encryption at rest for Amazon OpenSearch Serverless.
445 |
# File 'sig/client.rbs', line 445
def get_security_policy: (
|
#list_access_policies(params = {}) ⇒ Types::ListAccessPoliciesResponse
Returns information about a list of OpenSearch Serverless access policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
457 |
# File 'sig/client.rbs', line 457
def list_access_policies: (
|
#list_collection_groups(params = {}) ⇒ Types::ListCollectionGroupsResponse
Returns a list of collection groups. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
471 |
# File 'sig/client.rbs', line 471
def list_collection_groups: (
|
#list_collections(params = {}) ⇒ Types::ListCollectionsResponse
Lists all OpenSearch Serverless collections. For more information, see Creating and managing Amazon OpenSearch Serverless collections.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
483 |
# File 'sig/client.rbs', line 483
def list_collections: (
|
#list_lifecycle_policies(params = {}) ⇒ Types::ListLifecyclePoliciesResponse
Returns a list of OpenSearch Serverless lifecycle policies. For more information, see Viewing data lifecycle policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
500 |
# File 'sig/client.rbs', line 500
def list_lifecycle_policies: (
|
#list_security_configs(params = {}) ⇒ Types::ListSecurityConfigsResponse
Returns information about configured OpenSearch Serverless security configurations. For more information, see SAML authentication for Amazon OpenSearch Serverless.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
514 |
# File 'sig/client.rbs', line 514
def list_security_configs: (
|
#list_security_policies(params = {}) ⇒ Types::ListSecurityPoliciesResponse
Returns information about configured OpenSearch Serverless security policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
527 |
# File 'sig/client.rbs', line 527
def list_security_policies: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the tags for an OpenSearch Serverless resource. For more information, see Tagging Amazon OpenSearch Serverless collections.
540 |
# File 'sig/client.rbs', line 540
def list_tags_for_resource: (
|
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Returns the OpenSearch Serverless-managed interface VPC endpoints associated with the current account. For more information, see Access Amazon OpenSearch Serverless using an interface endpoint.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
551 |
# File 'sig/client.rbs', line 551
def list_vpc_endpoints: (
|
#tag_resource(params = {}) ⇒ Struct
Associates tags with an OpenSearch Serverless resource. For more information, see Tagging Amazon OpenSearch Serverless collections.
564 |
# File 'sig/client.rbs', line 564
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes a tag or set of tags from an OpenSearch Serverless resource. For more information, see Tagging Amazon OpenSearch Serverless collections.
579 |
# File 'sig/client.rbs', line 579
def untag_resource: (
|
#update_access_policy(params = {}) ⇒ Types::UpdateAccessPolicyResponse
Updates an OpenSearch Serverless access policy. For more information, see Data access control for Amazon OpenSearch Serverless.
590 |
# File 'sig/client.rbs', line 590
def update_access_policy: (
|
#update_account_settings(params = {}) ⇒ Types::UpdateAccountSettingsResponse
Update the OpenSearch Serverless settings for the current Amazon Web Services account. For more information, see Managing capacity limits for Amazon OpenSearch Serverless.
605 |
# File 'sig/client.rbs', line 605
def update_account_settings: (
|
#update_collection(params = {}) ⇒ Types::UpdateCollectionResponse
Updates an OpenSearch Serverless collection.
618 |
# File 'sig/client.rbs', line 618
def update_collection: (
|
#update_collection_group(params = {}) ⇒ Types::UpdateCollectionGroupResponse
Updates the description and capacity limits of a collection group.
634 |
# File 'sig/client.rbs', line 634
def update_collection_group: (
|
#update_index(params = {}) ⇒ Struct
Updates an existing index in an OpenSearch Serverless collection. This operation allows you to modify the index schema, including adding new fields or changing field mappings. You can also enable automatic semantic enrichment ingestion and search. For more information, see About automatic semantic enrichment.
651 |
# File 'sig/client.rbs', line 651
def update_index: (
|
#update_lifecycle_policy(params = {}) ⇒ Types::UpdateLifecyclePolicyResponse
Updates an OpenSearch Serverless access policy. For more information, see Updating data lifecycle policies.
664 |
# File 'sig/client.rbs', line 664
def update_lifecycle_policy: (
|
#update_security_config(params = {}) ⇒ Types::UpdateSecurityConfigResponse
Updates a security configuration for OpenSearch Serverless. For more information, see SAML authentication for Amazon OpenSearch Serverless.
679 |
# File 'sig/client.rbs', line 679
def update_security_config: (
|
#update_security_policy(params = {}) ⇒ Types::UpdateSecurityPolicyResponse
Updates an OpenSearch Serverless security policy. For more information, see Network access for Amazon OpenSearch Serverless and Encryption at rest for Amazon OpenSearch Serverless.
707 |
# File 'sig/client.rbs', line 707
def update_security_policy: (
|
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Updates an OpenSearch Serverless-managed interface endpoint. For more information, see Access Amazon OpenSearch Serverless using an interface endpoint.
722 |
# File 'sig/client.rbs', line 722
def update_vpc_endpoint: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3010 3011 3012 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 3010 def waiter_names [] end |