Class: Aws::OpenSearchServerless::Types::CollectionDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Details about each OpenSearch Serverless collection, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints for federal government workloads.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#collection_endpointString

Collection-specific endpoint used to submit index, search, and data upload requests to an OpenSearch Serverless collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#collection_group_nameString

The name of the collection group that contains this collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateInteger

The Epoch time when the collection was created.

Returns:

  • (Integer)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_endpointString

Collection-specific endpoint used to access OpenSearch Dashboards.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protectionString

Indicates whether deletion protection is ‘ENABLED` or `DISABLED` for the collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#failure_codeString

A failure code associated with the request.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#failure_messageString

A message associated with the failure code.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#fips_endpointsTypes::FipsEndpoints

FIPS-compliant endpoints for the collection. These endpoints use FIPS 140-3 validated cryptographic modules and are required for federal government workloads that must comply with FedRAMP security standards.



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The ARN of the Amazon Web Services KMS key used to encrypt the collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateInteger

The date and time when the collection was last modified.

Returns:

  • (Integer)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#standby_replicasString

Details about an OpenSearch Serverless collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of collection.

Returns:

  • (String)


431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#vector_optionsTypes::VectorOptions

Configuration options for vector search capabilities in the collection.



431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431

class CollectionDetail < Struct.new(
  :id,
  :name,
  :status,
  :type,
  :description,
  :arn,
  :kms_key_arn,
  :standby_replicas,
  :deletion_protection,
  :vector_options,
  :created_date,
  :last_modified_date,
  :collection_endpoint,
  :dashboard_endpoint,
  :fips_endpoints,
  :failure_code,
  :failure_message,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end