Class: Aws::OpenSearchServerless::Types::CollectionGroupDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Details about a collection group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the collection group.

Returns:

  • (String)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_limits ⇒ Types::CollectionGroupCapacityLimits

The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#created_date ⇒ Integer

The Epoch time when the collection group was created.

Returns:

  • (Integer)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#current_capacity ⇒ Types::CurrentCapacity

Current search and indexing capacity for the collection group.



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#description ⇒ String

The description of the collection group.

Returns:

  • (String)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#generation ⇒ String

The generation of Amazon OpenSearch Serverless for the collection group.

Returns:

  • (String)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the collection group.

Returns:

  • (String)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the collection group.

Returns:

  • (String)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_collections ⇒ Integer

The number of collections associated with the collection group.

Returns:

  • (Integer)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#standby_replicas ⇒ String

Indicates whether standby replicas are used for the collection group.

Returns:

  • (String)


593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#tags ⇒ Array<Types::Tag>

A map of key-value pairs associated with the collection group.

Returns:



593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 593

class CollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :current_capacity,
  :number_of_collections,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end