Class: Aws::OpenSearchServerless::Types::CollectionGroupErrorDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::CollectionGroupErrorDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Error details for a collection group operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#error_code ⇒ String
The error code for the request.
-
#error_message ⇒ String
A description of the error.
-
#id ⇒ String
If the request contains collection group IDs, the response includes the IDs provided in the request.
-
#name ⇒ String
If the request contains collection group names, the response includes the names provided in the request.
Instance Attribute Details
#error_code ⇒ String
The error code for the request. For example, ‘NOT_FOUND`.
595 596 597 598 599 600 601 602 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 595 class CollectionGroupErrorDetail < Struct.new( :id, :name, :error_message, :error_code) SENSITIVE = [] include Aws::Structure end |
#error_message ⇒ String
A description of the error. For example, ‘The specified Collection Group is not found.`
595 596 597 598 599 600 601 602 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 595 class CollectionGroupErrorDetail < Struct.new( :id, :name, :error_message, :error_code) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
If the request contains collection group IDs, the response includes the IDs provided in the request.
595 596 597 598 599 600 601 602 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 595 class CollectionGroupErrorDetail < Struct.new( :id, :name, :error_message, :error_code) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
If the request contains collection group names, the response includes the names provided in the request.
595 596 597 598 599 600 601 602 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 595 class CollectionGroupErrorDetail < Struct.new( :id, :name, :error_message, :error_code) SENSITIVE = [] include Aws::Structure end |