Class: Aws::OpenSearchServerless::Types::CollectionGroupSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Summary information about a collection group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the collection group.

Returns:

  • (String)


676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 676

class CollectionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :number_of_collections,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_limits ⇒ Types::CollectionGroupCapacityLimits

Capacity limits for a collection group. These limits define the minimum and maximum OpenSearch Compute Units (OCUs) for indexing and search operations that can be used by collections in the group.



676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 676

class CollectionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :number_of_collections,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#created_date ⇒ Integer

The Epoch time when the collection group was created.

Returns:

  • (Integer)


676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 676

class CollectionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :number_of_collections,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#generation ⇒ String

The generation of Amazon OpenSearch Serverless for the collection group.

Returns:

  • (String)


676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 676

class CollectionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :number_of_collections,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the collection group.

Returns:

  • (String)


676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 676

class CollectionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :number_of_collections,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the collection group.

Returns:

  • (String)


676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 676

class CollectionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :number_of_collections,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#number_of_collections ⇒ Integer

The number of collections within the collection group.

Returns:

  • (Integer)


676
677
678
679
680
681
682
683
684
685
686
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 676

class CollectionGroupSummary < Struct.new(
  :id,
  :arn,
  :name,
  :number_of_collections,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end