Class: Aws::OpenSearchServerless::Types::CollectionSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Details about each OpenSearch Serverless collection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arn ⇒ String

The Amazon Resource Name (ARN) of the collection.

Returns:

  • (String)


717
718
719
720
721
722
723
724
725
726
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 717

class CollectionSummary < Struct.new(
  :id,
  :name,
  :status,
  :arn,
  :kms_key_arn,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#collection_group_name ⇒ String

The name of the collection group that contains this collection.

Returns:

  • (String)


717
718
719
720
721
722
723
724
725
726
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 717

class CollectionSummary < Struct.new(
  :id,
  :name,
  :status,
  :arn,
  :kms_key_arn,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#id ⇒ String

The unique identifier of the collection.

Returns:

  • (String)


717
718
719
720
721
722
723
724
725
726
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 717

class CollectionSummary < Struct.new(
  :id,
  :name,
  :status,
  :arn,
  :kms_key_arn,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arn ⇒ String

The ARN of the Amazon Web Services Key Management Service key used to encrypt the collection.

Returns:

  • (String)


717
718
719
720
721
722
723
724
725
726
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 717

class CollectionSummary < Struct.new(
  :id,
  :name,
  :status,
  :arn,
  :kms_key_arn,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#name ⇒ String

The name of the collection.

Returns:

  • (String)


717
718
719
720
721
722
723
724
725
726
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 717

class CollectionSummary < Struct.new(
  :id,
  :name,
  :status,
  :arn,
  :kms_key_arn,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end

#status ⇒ String

The current status of the collection.

Returns:

  • (String)


717
718
719
720
721
722
723
724
725
726
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 717

class CollectionSummary < Struct.new(
  :id,
  :name,
  :status,
  :arn,
  :kms_key_arn,
  :collection_group_name)
  SENSITIVE = []
  include Aws::Structure
end