Class: Aws::OpenSearchServerless::Types::CreateCollectionGroupDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Details about the created collection group.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the collection group.

Returns:

  • (String)


913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#capacity_limitsTypes::CollectionGroupCapacityLimits

The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).



913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateInteger

The Epoch time when the collection group was created.

Returns:

  • (Integer)


913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

The description of the collection group.

Returns:

  • (String)


913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#generationString

The generation of Amazon OpenSearch Serverless for the collection group.

Returns:

  • (String)


913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the collection group.

Returns:

  • (String)


913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the collection group.

Returns:

  • (String)


913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#standby_replicasString

Indicates whether standby replicas are used for the collection group.

Returns:

  • (String)


913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A map of key-value pairs associated with the collection group.

Returns:



913
914
915
916
917
918
919
920
921
922
923
924
925
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 913

class CreateCollectionGroupDetail < Struct.new(
  :id,
  :arn,
  :name,
  :standby_replicas,
  :description,
  :tags,
  :created_date,
  :capacity_limits,
  :generation)
  SENSITIVE = []
  include Aws::Structure
end