Class: Aws::OpenSearchServerless::Types::CreateCollectionGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::CreateCollectionGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#capacity_limits ⇒ Types::CollectionGroupCapacityLimits
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
-
#description ⇒ String
A description of the collection group.
-
#generation ⇒ String
The generation of Amazon OpenSearch Serverless for the collection group.
-
#name ⇒ String
The name of the collection group.
-
#standby_replicas ⇒ String
Indicates whether standby replicas should be used for a collection group.
-
#tags ⇒ Array<Types::Tag>
An arbitrary set of tags (key–value pairs) to associate with the OpenSearch Serverless collection group.
Instance Attribute Details
#capacity_limits ⇒ Types::CollectionGroupCapacityLimits
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs). These limits control the maximum and minimum capacity for collections within the group.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 966 class CreateCollectionGroupRequest < Struct.new( :name, :standby_replicas, :description, :tags, :capacity_limits, :generation, :client_token) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 966 class CreateCollectionGroupRequest < Struct.new( :name, :standby_replicas, :description, :tags, :capacity_limits, :generation, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the collection group.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 966 class CreateCollectionGroupRequest < Struct.new( :name, :standby_replicas, :description, :tags, :capacity_limits, :generation, :client_token) SENSITIVE = [] include Aws::Structure end |
#generation ⇒ String
The generation of Amazon OpenSearch Serverless for the collection group. Valid values are ‘CLASSIC` and `NEXTGEN`.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 966 class CreateCollectionGroupRequest < Struct.new( :name, :standby_replicas, :description, :tags, :capacity_limits, :generation, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the collection group.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 966 class CreateCollectionGroupRequest < Struct.new( :name, :standby_replicas, :description, :tags, :capacity_limits, :generation, :client_token) SENSITIVE = [] include Aws::Structure end |
#standby_replicas ⇒ String
Indicates whether standby replicas should be used for a collection group.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 966 class CreateCollectionGroupRequest < Struct.new( :name, :standby_replicas, :description, :tags, :capacity_limits, :generation, :client_token) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
An arbitrary set of tags (key–value pairs) to associate with the OpenSearch Serverless collection group.
966 967 968 969 970 971 972 973 974 975 976 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 966 class CreateCollectionGroupRequest < Struct.new( :name, :standby_replicas, :description, :tags, :capacity_limits, :generation, :client_token) SENSITIVE = [] include Aws::Structure end |