Class: Aws::OpenSearchServerless::Types::CreateVpcEndpointRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::CreateVpcEndpointRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
-
#name ⇒ String
The name of the interface endpoint.
-
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups that define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
-
#subnet_ids ⇒ Array<String>
The ID of one or more subnets from which you’ll access OpenSearch Serverless.
-
#vpc_id ⇒ String
The ID of the VPC from which you’ll access OpenSearch Serverless.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1343 class CreateVpcEndpointRequest < Struct.new( :name, :vpc_id, :subnet_ids, :security_group_ids, :client_token) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the interface endpoint.
1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1343 class CreateVpcEndpointRequest < Struct.new( :name, :vpc_id, :subnet_ids, :security_group_ids, :client_token) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups that define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1343 class CreateVpcEndpointRequest < Struct.new( :name, :vpc_id, :subnet_ids, :security_group_ids, :client_token) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The ID of one or more subnets from which you’ll access OpenSearch Serverless.
1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1343 class CreateVpcEndpointRequest < Struct.new( :name, :vpc_id, :subnet_ids, :security_group_ids, :client_token) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC from which you’ll access OpenSearch Serverless.
1343 1344 1345 1346 1347 1348 1349 1350 1351 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1343 class CreateVpcEndpointRequest < Struct.new( :name, :vpc_id, :subnet_ids, :security_group_ids, :client_token) SENSITIVE = [] include Aws::Structure end |