Class: Aws::OpenSearchServerless::Types::EffectiveLifecyclePolicyDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::EffectiveLifecyclePolicyDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Error information for an OpenSearch Serverless request.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#no_min_retention_period ⇒ Boolean
The minimum number of index retention days set.
-
#policy_name ⇒ String
The name of the lifecycle policy.
-
#resource ⇒ String
The name of the OpenSearch Serverless index resource.
-
#resource_type ⇒ String
The type of OpenSearch Serverless resource.
-
#retention_period ⇒ String
The minimum number of index retention in days or hours.
-
#type ⇒ String
The type of lifecycle policy.
Instance Attribute Details
#no_min_retention_period ⇒ Boolean
The minimum number of index retention days set. That is an optional param that will return as ‘true` if the minimum number of days or hours is not set to a index resource.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1708 class EffectiveLifecyclePolicyDetail < Struct.new( :type, :resource, :policy_name, :resource_type, :retention_period, :no_min_retention_period) SENSITIVE = [] include Aws::Structure end |
#policy_name ⇒ String
The name of the lifecycle policy.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1708 class EffectiveLifecyclePolicyDetail < Struct.new( :type, :resource, :policy_name, :resource_type, :retention_period, :no_min_retention_period) SENSITIVE = [] include Aws::Structure end |
#resource ⇒ String
The name of the OpenSearch Serverless index resource.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1708 class EffectiveLifecyclePolicyDetail < Struct.new( :type, :resource, :policy_name, :resource_type, :retention_period, :no_min_retention_period) SENSITIVE = [] include Aws::Structure end |
#resource_type ⇒ String
The type of OpenSearch Serverless resource. Currently, the only supported resource is ‘index`.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1708 class EffectiveLifecyclePolicyDetail < Struct.new( :type, :resource, :policy_name, :resource_type, :retention_period, :no_min_retention_period) SENSITIVE = [] include Aws::Structure end |
#retention_period ⇒ String
The minimum number of index retention in days or hours. This is an optional parameter that will return only if it’s set.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1708 class EffectiveLifecyclePolicyDetail < Struct.new( :type, :resource, :policy_name, :resource_type, :retention_period, :no_min_retention_period) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of lifecycle policy.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 1708 class EffectiveLifecyclePolicyDetail < Struct.new( :type, :resource, :policy_name, :resource_type, :retention_period, :no_min_retention_period) SENSITIVE = [] include Aws::Structure end |