Class: Aws::OpenSearchServerless::Types::LifecyclePolicyDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::LifecyclePolicyDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Details about an OpenSearch Serverless lifecycle policy.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_date ⇒ Integer
The date the lifecycle policy was created.
-
#description ⇒ String
The description of the lifecycle policy.
-
#last_modified_date ⇒ Integer
The timestamp of when the lifecycle policy was last modified.
-
#name ⇒ String
The name of the lifecycle policy.
-
#policy ⇒ Hash, ...
The JSON policy document without any whitespaces.
-
#policy_version ⇒ String
The version of the lifecycle policy.
-
#type ⇒ String
The type of lifecycle policy.
Instance Attribute Details
#created_date ⇒ Integer
The date the lifecycle policy was created.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2085 class LifecyclePolicyDetail < Struct.new( :type, :name, :policy_version, :description, :policy, :created_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the lifecycle policy.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2085 class LifecyclePolicyDetail < Struct.new( :type, :name, :policy_version, :description, :policy, :created_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Integer
The timestamp of when the lifecycle policy was last modified.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2085 class LifecyclePolicyDetail < Struct.new( :type, :name, :policy_version, :description, :policy, :created_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the lifecycle policy.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2085 class LifecyclePolicyDetail < Struct.new( :type, :name, :policy_version, :description, :policy, :created_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ Hash, ...
The JSON policy document without any whitespaces.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2085 class LifecyclePolicyDetail < Struct.new( :type, :name, :policy_version, :description, :policy, :created_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#policy_version ⇒ String
The version of the lifecycle policy.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2085 class LifecyclePolicyDetail < Struct.new( :type, :name, :policy_version, :description, :policy, :created_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of lifecycle policy.
2085 2086 2087 2088 2089 2090 2091 2092 2093 2094 2095 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2085 class LifecyclePolicyDetail < Struct.new( :type, :name, :policy_version, :description, :policy, :created_date, :last_modified_date) SENSITIVE = [] include Aws::Structure end |