Class: Aws::OpenSearchServerless::Types::ListVpcEndpointsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_results ⇒ Integer

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results. The default is 20.

Returns:

  • (Integer)


2558
2559
2560
2561
2562
2563
2564
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2558

class ListVpcEndpointsRequest < Struct.new(
  :vpc_endpoint_filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_token ⇒ String

If your initial ListVpcEndpoints operation returns a nextToken, you can include the returned nextToken in subsequent ListVpcEndpoints operations, which returns results in the next page.

Returns:

  • (String)


2558
2559
2560
2561
2562
2563
2564
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2558

class ListVpcEndpointsRequest < Struct.new(
  :vpc_endpoint_filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_endpoint_filters ⇒ Types::VpcEndpointFilters

Filter the results according to the current status of the VPC endpoint. Possible statuses are CREATING, DELETING, UPDATING, ACTIVE, and FAILED.



2558
2559
2560
2561
2562
2563
2564
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2558

class ListVpcEndpointsRequest < Struct.new(
  :vpc_endpoint_filters,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end