Class: Aws::OpenSearchServerless::Types::UpdateCollectionGroupDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::UpdateCollectionGroupDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Details about the updated collection group.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the collection group.
-
#capacity_limits ⇒ Types::CollectionGroupCapacityLimits
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
-
#created_date ⇒ Integer
The Epoch time when the collection group was created.
-
#description ⇒ String
The description of the collection group.
-
#generation ⇒ String
The generation of Amazon OpenSearch Serverless for the collection group.
-
#id ⇒ String
The unique identifier of the collection group.
-
#last_modified_date ⇒ Integer
The date and time when the collection group was last modified.
-
#name ⇒ String
The name of the collection group.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the collection group.
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |
#capacity_limits ⇒ Types::CollectionGroupCapacityLimits
The capacity limits for the collection group, in OpenSearch Compute Units (OCUs).
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Integer
The Epoch time when the collection group was created.
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the collection group.
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |
#generation ⇒ String
The generation of Amazon OpenSearch Serverless for the collection group.
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the collection group.
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Integer
The date and time when the collection group was last modified.
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the collection group.
3153 3154 3155 3156 3157 3158 3159 3160 3161 3162 3163 3164 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3153 class UpdateCollectionGroupDetail < Struct.new( :id, :arn, :name, :description, :capacity_limits, :created_date, :last_modified_date, :generation) SENSITIVE = [] include Aws::Structure end |