Class: Aws::OpenSearchServerless::Types::UpdateCollectionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::UpdateCollectionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
-
#deletion_protection ⇒ String
Indicates whether to enable or disable deletion protection for the collection.
-
#description ⇒ String
A description of the collection.
-
#id ⇒ String
The unique identifier of the collection.
-
#vector_options ⇒ Types::VectorOptions
Configuration options for vector search capabilities in the collection.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3238 3239 3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3238 class UpdateCollectionRequest < Struct.new( :id, :description, :vector_options, :deletion_protection, :client_token) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ String
Indicates whether to enable or disable deletion protection for the collection. When set to ‘ENABLED`, the collection cannot be deleted.
3238 3239 3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3238 class UpdateCollectionRequest < Struct.new( :id, :description, :vector_options, :deletion_protection, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the collection.
3238 3239 3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3238 class UpdateCollectionRequest < Struct.new( :id, :description, :vector_options, :deletion_protection, :client_token) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the collection.
3238 3239 3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3238 class UpdateCollectionRequest < Struct.new( :id, :description, :vector_options, :deletion_protection, :client_token) SENSITIVE = [] include Aws::Structure end |
#vector_options ⇒ Types::VectorOptions
Configuration options for vector search capabilities in the collection.
3238 3239 3240 3241 3242 3243 3244 3245 3246 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3238 class UpdateCollectionRequest < Struct.new( :id, :description, :vector_options, :deletion_protection, :client_token) SENSITIVE = [] include Aws::Structure end |