Class: Aws::OpenSearchServerless::Types::UpdateSecurityConfigRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::UpdateSecurityConfigRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
-
#config_version ⇒ String
The version of the security configuration to be updated.
-
#description ⇒ String
A description of the security configuration.
-
#iam_federation_options ⇒ Types::IamFederationConfigOptions
Describes IAM federation options in the form of a key-value map for updating an existing security configuration.
-
#iam_identity_center_options_updates ⇒ Types::UpdateIamIdentityCenterConfigOptions
Describes IAM Identity Center options in the form of a key-value map.
-
#id ⇒ String
The security configuration identifier.
-
#saml_options ⇒ Types::SamlConfigOptions
SAML options in in the form of a key-value map.
Instance Attribute Details
#client_token ⇒ String
Unique, case-sensitive identifier to ensure idempotency of the request.
**A suitable default value is auto-generated.** You should normally not need to pass this option.
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3405 class UpdateSecurityConfigRequest < Struct.new( :id, :config_version, :description, :saml_options, :iam_identity_center_options_updates, :iam_federation_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#config_version ⇒ String
The version of the security configuration to be updated. You can find the most recent version of a security configuration using the ‘GetSecurityPolicy` command.
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3405 class UpdateSecurityConfigRequest < Struct.new( :id, :config_version, :description, :saml_options, :iam_identity_center_options_updates, :iam_federation_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the security configuration.
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3405 class UpdateSecurityConfigRequest < Struct.new( :id, :config_version, :description, :saml_options, :iam_identity_center_options_updates, :iam_federation_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#iam_federation_options ⇒ Types::IamFederationConfigOptions
Describes IAM federation options in the form of a key-value map for updating an existing security configuration. Use this field to modify IAM federation settings for the security configuration.
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3405 class UpdateSecurityConfigRequest < Struct.new( :id, :config_version, :description, :saml_options, :iam_identity_center_options_updates, :iam_federation_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#iam_identity_center_options_updates ⇒ Types::UpdateIamIdentityCenterConfigOptions
Describes IAM Identity Center options in the form of a key-value map.
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3405 class UpdateSecurityConfigRequest < Struct.new( :id, :config_version, :description, :saml_options, :iam_identity_center_options_updates, :iam_federation_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The security configuration identifier. For SAML the ID will be ‘saml/<accountId>/<idpProviderName>`. For example, `saml/123456789123/OKTADev`.
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3405 class UpdateSecurityConfigRequest < Struct.new( :id, :config_version, :description, :saml_options, :iam_identity_center_options_updates, :iam_federation_options, :client_token) SENSITIVE = [] include Aws::Structure end |
#saml_options ⇒ Types::SamlConfigOptions
SAML options in in the form of a key-value map.
3405 3406 3407 3408 3409 3410 3411 3412 3413 3414 3415 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3405 class UpdateSecurityConfigRequest < Struct.new( :id, :config_version, :description, :saml_options, :iam_identity_center_options_updates, :iam_federation_options, :client_token) SENSITIVE = [] include Aws::Structure end |