Class: Aws::OpenSearchServerless::Types::UpdateVpcEndpointDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::UpdateVpcEndpointDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Update details for an OpenSearch Serverless-managed interface endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the endpoint.
-
#last_modified_date ⇒ Integer
The timestamp of when the endpoint was last modified.
-
#name ⇒ String
The name of the endpoint.
-
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups that define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
-
#status ⇒ String
The current status of the endpoint update process.
-
#subnet_ids ⇒ Array<String>
The ID of the subnets from which you access OpenSearch Serverless.
Instance Attribute Details
#id ⇒ String
The unique identifier of the endpoint.
3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3514 class UpdateVpcEndpointDetail < Struct.new( :id, :name, :status, :subnet_ids, :security_group_ids, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Integer
The timestamp of when the endpoint was last modified.
3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3514 class UpdateVpcEndpointDetail < Struct.new( :id, :name, :status, :subnet_ids, :security_group_ids, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the endpoint.
3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3514 class UpdateVpcEndpointDetail < Struct.new( :id, :name, :status, :subnet_ids, :security_group_ids, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups that define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3514 class UpdateVpcEndpointDetail < Struct.new( :id, :name, :status, :subnet_ids, :security_group_ids, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the endpoint update process.
3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3514 class UpdateVpcEndpointDetail < Struct.new( :id, :name, :status, :subnet_ids, :security_group_ids, :last_modified_date) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The ID of the subnets from which you access OpenSearch Serverless.
3514 3515 3516 3517 3518 3519 3520 3521 3522 3523 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3514 class UpdateVpcEndpointDetail < Struct.new( :id, :name, :status, :subnet_ids, :security_group_ids, :last_modified_date) SENSITIVE = [] include Aws::Structure end |