Class: Aws::OpenSearchServerless::Types::UpdateVpcEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#add_security_group_idsArray<String>

The unique identifiers of the security groups to add to the endpoint. Security groups define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.

Returns:

  • (Array<String>)


3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3558

class UpdateVpcEndpointRequest < Struct.new(
  :id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#add_subnet_idsArray<String>

The ID of one or more subnets to add to the endpoint.

Returns:

  • (Array<String>)


3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3558

class UpdateVpcEndpointRequest < Struct.new(
  :id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

Unique, case-sensitive identifier to ensure idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.

Returns:

  • (String)


3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3558

class UpdateVpcEndpointRequest < Struct.new(
  :id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the interface endpoint to update.

Returns:

  • (String)


3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3558

class UpdateVpcEndpointRequest < Struct.new(
  :id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#remove_security_group_idsArray<String>

The unique identifiers of the security groups to remove from the endpoint.

Returns:

  • (Array<String>)


3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3558

class UpdateVpcEndpointRequest < Struct.new(
  :id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end

#remove_subnet_idsArray<String>

The unique identifiers of the subnets to remove from the endpoint.

Returns:

  • (Array<String>)


3558
3559
3560
3561
3562
3563
3564
3565
3566
3567
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3558

class UpdateVpcEndpointRequest < Struct.new(
  :id,
  :add_subnet_ids,
  :remove_subnet_ids,
  :add_security_group_ids,
  :remove_security_group_ids,
  :client_token)
  SENSITIVE = []
  include Aws::Structure
end