Class: Aws::OpenSearchServerless::Types::VpcEndpointDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::VpcEndpointDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Details about an OpenSearch Serverless-managed interface endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#created_date ⇒ Integer
The date the endpoint was created.
-
#failure_code ⇒ String
A failure code associated with the request.
-
#failure_message ⇒ String
A message associated with the failure code.
-
#id ⇒ String
The unique identifier of the endpoint.
-
#name ⇒ String
The name of the endpoint.
-
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups that define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
-
#status ⇒ String
The current status of the endpoint.
-
#subnet_ids ⇒ Array<String>
The ID of the subnets from which you access OpenSearch Serverless.
-
#vpc_id ⇒ String
The ID of the VPC from which you access OpenSearch Serverless.
Instance Attribute Details
#created_date ⇒ Integer
The date the endpoint was created.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
A failure code associated with the request.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
A message associated with the failure code.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the endpoint.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the endpoint.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#security_group_ids ⇒ Array<String>
The unique identifiers of the security groups that define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the endpoint.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#subnet_ids ⇒ Array<String>
The ID of the subnets from which you access OpenSearch Serverless.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
The ID of the VPC from which you access OpenSearch Serverless.
3653 3654 3655 3656 3657 3658 3659 3660 3661 3662 3663 3664 3665 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 3653 class VpcEndpointDetail < Struct.new( :id, :name, :vpc_id, :subnet_ids, :security_group_ids, :status, :created_date, :failure_code, :failure_message) SENSITIVE = [] include Aws::Structure end |