Class: Aws::OpenSearchServerless::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::OpenSearchServerless::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-opensearchserverless/client.rb
Overview
An API client for OpenSearchServerless. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::OpenSearchServerless::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_collection(params = {}) ⇒ Types::BatchGetCollectionResponse
Returns attributes for one or more collections, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints.
-
#batch_get_collection_group(params = {}) ⇒ Types::BatchGetCollectionGroupResponse
Returns attributes for one or more collection groups, including capacity limits and the number of collections in each group.
-
#batch_get_effective_lifecycle_policy(params = {}) ⇒ Types::BatchGetEffectiveLifecyclePolicyResponse
Returns a list of successful and failed retrievals for the OpenSearch Serverless indexes.
-
#batch_get_lifecycle_policy(params = {}) ⇒ Types::BatchGetLifecyclePolicyResponse
Returns one or more configured OpenSearch Serverless lifecycle policies.
-
#batch_get_vpc_endpoint(params = {}) ⇒ Types::BatchGetVpcEndpointResponse
Returns attributes for one or more VPC endpoints associated with the current account.
-
#create_access_policy(params = {}) ⇒ Types::CreateAccessPolicyResponse
Creates a data access policy for OpenSearch Serverless.
-
#create_collection(params = {}) ⇒ Types::CreateCollectionResponse
Creates a new OpenSearch Serverless collection.
-
#create_collection_group(params = {}) ⇒ Types::CreateCollectionGroupResponse
Creates a collection group within OpenSearch Serverless.
-
#create_index(params = {}) ⇒ Struct
Creates an index within an OpenSearch Serverless collection.
-
#create_lifecycle_policy(params = {}) ⇒ Types::CreateLifecyclePolicyResponse
Creates a lifecyle policy to be applied to OpenSearch Serverless indexes.
-
#create_security_config(params = {}) ⇒ Types::CreateSecurityConfigResponse
Specifies a security configuration for OpenSearch Serverless.
-
#create_security_policy(params = {}) ⇒ Types::CreateSecurityPolicyResponse
Creates a security policy to be used by one or more OpenSearch Serverless collections.
-
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an OpenSearch Serverless-managed interface VPC endpoint.
-
#delete_access_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless access policy.
-
#delete_collection(params = {}) ⇒ Types::DeleteCollectionResponse
Deletes an OpenSearch Serverless collection.
-
#delete_collection_group(params = {}) ⇒ Struct
Deletes a collection group.
-
#delete_index(params = {}) ⇒ Struct
Deletes an index from an OpenSearch Serverless collection.
-
#delete_lifecycle_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless lifecycle policy.
-
#delete_security_config(params = {}) ⇒ Struct
Deletes a security configuration for OpenSearch Serverless.
-
#delete_security_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless security policy.
-
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an OpenSearch Serverless-managed interface endpoint.
-
#get_access_policy(params = {}) ⇒ Types::GetAccessPolicyResponse
Returns an OpenSearch Serverless access policy.
-
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Returns account-level settings related to OpenSearch Serverless.
-
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an index in an OpenSearch Serverless collection, including its schema definition.
-
#get_policies_stats(params = {}) ⇒ Types::GetPoliciesStatsResponse
Returns statistical information about your OpenSearch Serverless access policies, security configurations, and security policies.
-
#get_security_config(params = {}) ⇒ Types::GetSecurityConfigResponse
Returns information about an OpenSearch Serverless security configuration.
-
#get_security_policy(params = {}) ⇒ Types::GetSecurityPolicyResponse
Returns information about a configured OpenSearch Serverless security policy.
-
#list_access_policies(params = {}) ⇒ Types::ListAccessPoliciesResponse
Returns information about a list of OpenSearch Serverless access policies.
-
#list_collection_groups(params = {}) ⇒ Types::ListCollectionGroupsResponse
Returns a list of collection groups.
-
#list_collections(params = {}) ⇒ Types::ListCollectionsResponse
Lists all OpenSearch Serverless collections.
-
#list_lifecycle_policies(params = {}) ⇒ Types::ListLifecyclePoliciesResponse
Returns a list of OpenSearch Serverless lifecycle policies.
-
#list_security_configs(params = {}) ⇒ Types::ListSecurityConfigsResponse
Returns information about configured OpenSearch Serverless security configurations.
-
#list_security_policies(params = {}) ⇒ Types::ListSecurityPoliciesResponse
Returns information about configured OpenSearch Serverless security policies.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the tags for an OpenSearch Serverless resource.
-
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Returns the OpenSearch Serverless-managed interface VPC endpoints associated with the current account.
-
#tag_resource(params = {}) ⇒ Struct
Associates tags with an OpenSearch Serverless resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes a tag or set of tags from an OpenSearch Serverless resource.
-
#update_access_policy(params = {}) ⇒ Types::UpdateAccessPolicyResponse
Updates an OpenSearch Serverless access policy.
-
#update_account_settings(params = {}) ⇒ Types::UpdateAccountSettingsResponse
Update the OpenSearch Serverless settings for the current Amazon Web Services account.
-
#update_collection(params = {}) ⇒ Types::UpdateCollectionResponse
Updates an OpenSearch Serverless collection.
-
#update_collection_group(params = {}) ⇒ Types::UpdateCollectionGroupResponse
Updates the description and capacity limits of a collection group.
-
#update_index(params = {}) ⇒ Struct
Updates an existing index in an OpenSearch Serverless collection.
-
#update_lifecycle_policy(params = {}) ⇒ Types::UpdateLifecyclePolicyResponse
Updates an OpenSearch Serverless access policy.
-
#update_security_config(params = {}) ⇒ Types::UpdateSecurityConfigResponse
Updates a security configuration for OpenSearch Serverless.
-
#update_security_policy(params = {}) ⇒ Types::UpdateSecurityPolicyResponse
Updates an OpenSearch Serverless security policy.
-
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Updates an OpenSearch Serverless-managed interface endpoint.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3017 3018 3019 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 3017 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3020 3021 3022 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 3020 def errors_module Errors end |
Instance Method Details
#batch_get_collection(params = {}) ⇒ Types::BatchGetCollectionResponse
Returns attributes for one or more collections, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints. For more information, see [Creating and managing Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html
550 551 552 553 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 550 def batch_get_collection(params = {}, = {}) req = build_request(:batch_get_collection, params) req.send_request() end |
#batch_get_collection_group(params = {}) ⇒ Types::BatchGetCollectionGroupResponse
Returns attributes for one or more collection groups, including capacity limits and the number of collections in each group. For more information, see [Creating and managing Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html
616 617 618 619 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 616 def batch_get_collection_group(params = {}, = {}) req = build_request(:batch_get_collection_group, params) req.send_request() end |
#batch_get_effective_lifecycle_policy(params = {}) ⇒ Types::BatchGetEffectiveLifecyclePolicyResponse
Returns a list of successful and failed retrievals for the OpenSearch Serverless indexes. For more information, see [Viewing data lifecycle policies].
667 668 669 670 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 667 def batch_get_effective_lifecycle_policy(params = {}, = {}) req = build_request(:batch_get_effective_lifecycle_policy, params) req.send_request() end |
#batch_get_lifecycle_policy(params = {}) ⇒ Types::BatchGetLifecyclePolicyResponse
Returns one or more configured OpenSearch Serverless lifecycle policies. For more information, see [Viewing data lifecycle policies].
718 719 720 721 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 718 def batch_get_lifecycle_policy(params = {}, = {}) req = build_request(:batch_get_lifecycle_policy, params) req.send_request() end |
#batch_get_vpc_endpoint(params = {}) ⇒ Types::BatchGetVpcEndpointResponse
Returns attributes for one or more VPC endpoints associated with the current account. For more information, see [Access Amazon OpenSearch Serverless using an interface endpoint].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html
768 769 770 771 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 768 def batch_get_vpc_endpoint(params = {}, = {}) req = build_request(:batch_get_vpc_endpoint, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2990 2991 2992 2993 2994 2995 2996 2997 2998 2999 3000 3001 3002 3003 3004 3005 3006 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2990 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::OpenSearchServerless') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-opensearchserverless' context[:gem_version] = '1.60.0' Seahorse::Client::Request.new(handlers, context) end |
#create_access_policy(params = {}) ⇒ Types::CreateAccessPolicyResponse
Creates a data access policy for OpenSearch Serverless. Access policies limit access to collections and the resources within them, and allow a user to access that data irrespective of the access mechanism or network source. For more information, see [Data access control for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html
830 831 832 833 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 830 def create_access_policy(params = {}, = {}) req = build_request(:create_access_policy, params) req.send_request() end |
#create_collection(params = {}) ⇒ Types::CreateCollectionResponse
Creates a new OpenSearch Serverless collection. For more information, see [Creating and managing Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html
929 930 931 932 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 929 def create_collection(params = {}, = {}) req = build_request(:create_collection, params) req.send_request() end |
#create_collection_group(params = {}) ⇒ Types::CreateCollectionGroupResponse
Creates a collection group within OpenSearch Serverless. Collection groups let you manage OpenSearch Compute Units (OCUs) at a group level, with multiple collections sharing the group’s capacity limits.
For more information, see [Managing collection groups].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-collection-groups.html
1021 1022 1023 1024 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1021 def create_collection_group(params = {}, = {}) req = build_request(:create_collection_group, params) req.send_request() end |
#create_index(params = {}) ⇒ Struct
Creates an index within an OpenSearch Serverless collection. Unlike other OpenSearch indexes, indexes created by this API are automatically configured to conduct automatic semantic enrichment ingestion and search. For more information, see [About automatic semantic enrichment] in the *OpenSearch User Guide*.
1067 1068 1069 1070 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1067 def create_index(params = {}, = {}) req = build_request(:create_index, params) req.send_request() end |
#create_lifecycle_policy(params = {}) ⇒ Types::CreateLifecyclePolicyResponse
Creates a lifecyle policy to be applied to OpenSearch Serverless indexes. Lifecycle policies define the number of days or hours to retain the data on an OpenSearch Serverless index. For more information, see [Creating data lifecycle policies].
1128 1129 1130 1131 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1128 def create_lifecycle_policy(params = {}, = {}) req = build_request(:create_lifecycle_policy, params) req.send_request() end |
#create_security_config(params = {}) ⇒ Types::CreateSecurityConfigResponse
Specifies a security configuration for OpenSearch Serverless. For more information, see [SAML authentication for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html
1226 1227 1228 1229 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1226 def create_security_config(params = {}, = {}) req = build_request(:create_security_config, params) req.send_request() end |
#create_security_policy(params = {}) ⇒ Types::CreateSecurityPolicyResponse
Creates a security policy to be used by one or more OpenSearch Serverless collections. Security policies provide access to a collection and its OpenSearch Dashboards endpoint from public networks or specific VPC endpoints. They also allow you to secure a collection with a KMS encryption key. For more information, see [Network access for Amazon OpenSearch Serverless] and [Encryption at rest for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-network.html [2]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-encryption.html
1291 1292 1293 1294 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1291 def create_security_policy(params = {}, = {}) req = build_request(:create_security_policy, params) req.send_request() end |
#create_vpc_endpoint(params = {}) ⇒ Types::CreateVpcEndpointResponse
Creates an OpenSearch Serverless-managed interface VPC endpoint. For more information, see [Access Amazon OpenSearch Serverless using an interface endpoint].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html
1350 1351 1352 1353 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1350 def create_vpc_endpoint(params = {}, = {}) req = build_request(:create_vpc_endpoint, params) req.send_request() end |
#delete_access_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless access policy. For more information, see [Data access control for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html
1389 1390 1391 1392 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1389 def delete_access_policy(params = {}, = {}) req = build_request(:delete_access_policy, params) req.send_request() end |
#delete_collection(params = {}) ⇒ Types::DeleteCollectionResponse
Deletes an OpenSearch Serverless collection. For more information, see [Creating and managing Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html
1439 1440 1441 1442 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1439 def delete_collection(params = {}, = {}) req = build_request(:delete_collection, params) req.send_request() end |
#delete_collection_group(params = {}) ⇒ Struct
Deletes a collection group. You can only delete empty collection groups that contain no collections. For more information, see [Creating and managing Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html
1475 1476 1477 1478 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1475 def delete_collection_group(params = {}, = {}) req = build_request(:delete_collection_group, params) req.send_request() end |
#delete_index(params = {}) ⇒ Struct
Deletes an index from an OpenSearch Serverless collection. Be aware that the index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see [About automatic semantic enrichment].
1509 1510 1511 1512 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1509 def delete_index(params = {}, = {}) req = build_request(:delete_index, params) req.send_request() end |
#delete_lifecycle_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless lifecycle policy. For more information, see [Deleting data lifecycle policies].
1548 1549 1550 1551 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1548 def delete_lifecycle_policy(params = {}, = {}) req = build_request(:delete_lifecycle_policy, params) req.send_request() end |
#delete_security_config(params = {}) ⇒ Struct
Deletes a security configuration for OpenSearch Serverless. For more information, see [SAML authentication for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html
1586 1587 1588 1589 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1586 def delete_security_config(params = {}, = {}) req = build_request(:delete_security_config, params) req.send_request() end |
#delete_security_policy(params = {}) ⇒ Struct
Deletes an OpenSearch Serverless security policy.
1620 1621 1622 1623 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1620 def delete_security_policy(params = {}, = {}) req = build_request(:delete_security_policy, params) req.send_request() end |
#delete_vpc_endpoint(params = {}) ⇒ Types::DeleteVpcEndpointResponse
Deletes an OpenSearch Serverless-managed interface endpoint. For more information, see [Access Amazon OpenSearch Serverless using an interface endpoint].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html
1664 1665 1666 1667 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1664 def delete_vpc_endpoint(params = {}, = {}) req = build_request(:delete_vpc_endpoint, params) req.send_request() end |
#get_access_policy(params = {}) ⇒ Types::GetAccessPolicyResponse
Returns an OpenSearch Serverless access policy. For more information, see [Data access control for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html
1706 1707 1708 1709 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1706 def get_access_policy(params = {}, = {}) req = build_request(:get_access_policy, params) req.send_request() end |
#get_account_settings(params = {}) ⇒ Types::GetAccountSettingsResponse
Returns account-level settings related to OpenSearch Serverless.
1726 1727 1728 1729 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1726 def get_account_settings(params = {}, = {}) req = build_request(:get_account_settings, params) req.send_request() end |
#get_index(params = {}) ⇒ Types::GetIndexResponse
Retrieves information about an index in an OpenSearch Serverless collection, including its schema definition. The index might be configured to conduct automatic semantic enrichment ingestion and search. For more information, see [About automatic semantic enrichment].
1766 1767 1768 1769 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1766 def get_index(params = {}, = {}) req = build_request(:get_index, params) req.send_request() end |
#get_policies_stats(params = {}) ⇒ Types::GetPoliciesStatsResponse
Returns statistical information about your OpenSearch Serverless access policies, security configurations, and security policies.
1795 1796 1797 1798 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1795 def get_policies_stats(params = {}, = {}) req = build_request(:get_policies_stats, params) req.send_request() end |
#get_security_config(params = {}) ⇒ Types::GetSecurityConfigResponse
Returns information about an OpenSearch Serverless security configuration. For more information, see [SAML authentication for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html
1847 1848 1849 1850 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1847 def get_security_config(params = {}, = {}) req = build_request(:get_security_config, params) req.send_request() end |
#get_security_policy(params = {}) ⇒ Types::GetSecurityPolicyResponse
Returns information about a configured OpenSearch Serverless security policy. For more information, see [Network access for Amazon OpenSearch Serverless] and [Encryption at rest for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-network.html [2]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-encryption.html
1892 1893 1894 1895 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1892 def get_security_policy(params = {}, = {}) req = build_request(:get_security_policy, params) req.send_request() end |
#list_access_policies(params = {}) ⇒ Types::ListAccessPoliciesResponse
Returns information about a list of OpenSearch Serverless access policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1949 1950 1951 1952 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 1949 def list_access_policies(params = {}, = {}) req = build_request(:list_access_policies, params) req.send_request() end |
#list_collection_groups(params = {}) ⇒ Types::ListCollectionGroupsResponse
Returns a list of collection groups. For more information, see [Creating and managing Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2004 2005 2006 2007 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2004 def list_collection_groups(params = {}, = {}) req = build_request(:list_collection_groups, params) req.send_request() end |
#list_collections(params = {}) ⇒ Types::ListCollectionsResponse
Lists all OpenSearch Serverless collections. For more information, see [Creating and managing Amazon OpenSearch Serverless collections].
<note markdown=“1”> Make sure to include an empty request body {} if you don’t include any collection filters in the request.
</note>
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-manage.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2067 2068 2069 2070 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2067 def list_collections(params = {}, = {}) req = build_request(:list_collections, params) req.send_request() end |
#list_lifecycle_policies(params = {}) ⇒ Types::ListLifecyclePoliciesResponse
Returns a list of OpenSearch Serverless lifecycle policies. For more information, see [Viewing data lifecycle policies].
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2128 2129 2130 2131 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2128 def list_lifecycle_policies(params = {}, = {}) req = build_request(:list_lifecycle_policies, params) req.send_request() end |
#list_security_configs(params = {}) ⇒ Types::ListSecurityConfigsResponse
Returns information about configured OpenSearch Serverless security configurations. For more information, see [SAML authentication for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2185 2186 2187 2188 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2185 def list_security_configs(params = {}, = {}) req = build_request(:list_security_configs, params) req.send_request() end |
#list_security_policies(params = {}) ⇒ Types::ListSecurityPoliciesResponse
Returns information about configured OpenSearch Serverless security policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2242 2243 2244 2245 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2242 def list_security_policies(params = {}, = {}) req = build_request(:list_security_policies, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Returns the tags for an OpenSearch Serverless resource. For more information, see [Tagging Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-collection.html
2280 2281 2282 2283 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2280 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_vpc_endpoints(params = {}) ⇒ Types::ListVpcEndpointsResponse
Returns the OpenSearch Serverless-managed interface VPC endpoints associated with the current account. For more information, see [Access Amazon OpenSearch Serverless using an interface endpoint].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2337 2338 2339 2340 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2337 def list_vpc_endpoints(params = {}, = {}) req = build_request(:list_vpc_endpoints, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Associates tags with an OpenSearch Serverless resource. For more information, see [Tagging Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-collection.html
2377 2378 2379 2380 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2377 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes a tag or set of tags from an OpenSearch Serverless resource. For more information, see [Tagging Amazon OpenSearch Serverless collections].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/tag-collection.html
2412 2413 2414 2415 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2412 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_access_policy(params = {}) ⇒ Types::UpdateAccessPolicyResponse
Updates an OpenSearch Serverless access policy. For more information, see [Data access control for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-data-access.html
2475 2476 2477 2478 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2475 def update_access_policy(params = {}, = {}) req = build_request(:update_access_policy, params) req.send_request() end |
#update_account_settings(params = {}) ⇒ Types::UpdateAccountSettingsResponse
Update the OpenSearch Serverless settings for the current Amazon Web Services account. For more information, see [Managing capacity limits for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-scaling.html
2520 2521 2522 2523 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2520 def update_account_settings(params = {}, = {}) req = build_request(:update_account_settings, params) req.send_request() end |
#update_collection(params = {}) ⇒ Types::UpdateCollectionResponse
Updates an OpenSearch Serverless collection.
2581 2582 2583 2584 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2581 def update_collection(params = {}, = {}) req = build_request(:update_collection, params) req.send_request() end |
#update_collection_group(params = {}) ⇒ Types::UpdateCollectionGroupResponse
Updates the description and capacity limits of a collection group.
2641 2642 2643 2644 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2641 def update_collection_group(params = {}, = {}) req = build_request(:update_collection_group, params) req.send_request() end |
#update_index(params = {}) ⇒ Struct
Updates an existing index in an OpenSearch Serverless collection. This operation allows you to modify the index schema, including adding new fields or changing field mappings. You can also enable automatic semantic enrichment ingestion and search. For more information, see [About automatic semantic enrichment].
2687 2688 2689 2690 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2687 def update_index(params = {}, = {}) req = build_request(:update_index, params) req.send_request() end |
#update_lifecycle_policy(params = {}) ⇒ Types::UpdateLifecyclePolicyResponse
Updates an OpenSearch Serverless access policy. For more information, see [Updating data lifecycle policies].
2750 2751 2752 2753 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2750 def update_lifecycle_policy(params = {}, = {}) req = build_request(:update_lifecycle_policy, params) req.send_request() end |
#update_security_config(params = {}) ⇒ Types::UpdateSecurityConfigResponse
Updates a security configuration for OpenSearch Serverless. For more information, see [SAML authentication for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-saml.html
2848 2849 2850 2851 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2848 def update_security_config(params = {}, = {}) req = build_request(:update_security_config, params) req.send_request() end |
#update_security_policy(params = {}) ⇒ Types::UpdateSecurityPolicyResponse
Updates an OpenSearch Serverless security policy. For more information, see [Network access for Amazon OpenSearch Serverless] and [Encryption at rest for Amazon OpenSearch Serverless].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-network.html [2]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-encryption.html
2913 2914 2915 2916 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2913 def update_security_policy(params = {}, = {}) req = build_request(:update_security_policy, params) req.send_request() end |
#update_vpc_endpoint(params = {}) ⇒ Types::UpdateVpcEndpointResponse
Updates an OpenSearch Serverless-managed interface endpoint. For more information, see [Access Amazon OpenSearch Serverless using an interface endpoint].
[1]: docs.aws.amazon.com/opensearch-service/latest/developerguide/serverless-vpc.html
2981 2982 2983 2984 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 2981 def update_vpc_endpoint(params = {}, = {}) req = build_request(:update_vpc_endpoint, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3010 3011 3012 |
# File 'lib/aws-sdk-opensearchserverless/client.rb', line 3010 def waiter_names [] end |