Class: Aws::OpenSearchServerless::Types::CollectionDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::CollectionDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Details about each OpenSearch Serverless collection, including the collection endpoint, the OpenSearch Dashboards endpoint, and FIPS-compliant endpoints for federal government workloads.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the collection.
-
#collection_endpoint ⇒ String
Collection-specific endpoint used to submit index, search, and data upload requests to an OpenSearch Serverless collection.
-
#collection_group_name ⇒ String
The name of the collection group that contains this collection.
-
#created_date ⇒ Integer
The Epoch time when the collection was created.
-
#dashboard_endpoint ⇒ String
Collection-specific endpoint used to access OpenSearch Dashboards.
-
#deletion_protection ⇒ String
Indicates whether deletion protection is ‘ENABLED` or `DISABLED` for the collection.
-
#description ⇒ String
A description of the collection.
-
#failure_code ⇒ String
A failure code associated with the request.
-
#failure_message ⇒ String
A message associated with the failure code.
-
#fips_endpoints ⇒ Types::FipsEndpoints
FIPS-compliant endpoints for the collection.
-
#id ⇒ String
A unique identifier for the collection.
-
#kms_key_arn ⇒ String
The ARN of the Amazon Web Services KMS key used to encrypt the collection.
-
#last_modified_date ⇒ Integer
The date and time when the collection was last modified.
-
#name ⇒ String
The name of the collection.
-
#standby_replicas ⇒ String
Details about an OpenSearch Serverless collection.
-
#status ⇒ String
The current status of the collection.
-
#type ⇒ String
The type of collection.
-
#vector_options ⇒ Types::VectorOptions
Configuration options for vector search capabilities in the collection.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#collection_endpoint ⇒ String
Collection-specific endpoint used to submit index, search, and data upload requests to an OpenSearch Serverless collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#collection_group_name ⇒ String
The name of the collection group that contains this collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Integer
The Epoch time when the collection was created.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#dashboard_endpoint ⇒ String
Collection-specific endpoint used to access OpenSearch Dashboards.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ String
Indicates whether deletion protection is ‘ENABLED` or `DISABLED` for the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#failure_code ⇒ String
A failure code associated with the request.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#failure_message ⇒ String
A message associated with the failure code.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#fips_endpoints ⇒ Types::FipsEndpoints
FIPS-compliant endpoints for the collection. These endpoints use FIPS 140-3 validated cryptographic modules and are required for federal government workloads that must comply with FedRAMP security standards.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
A unique identifier for the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The ARN of the Amazon Web Services KMS key used to encrypt the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Integer
The date and time when the collection was last modified.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#standby_replicas ⇒ String
Details about an OpenSearch Serverless collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#vector_options ⇒ Types::VectorOptions
Configuration options for vector search capabilities in the collection.
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 431 class CollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_endpoint, :dashboard_endpoint, :fips_endpoints, :failure_code, :failure_message, :collection_group_name) SENSITIVE = [] include Aws::Structure end |