Class: Aws::OpenSearchServerless::Types::CollectionDetail

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Details about each OpenSearch Serverless collection, including the collection endpoint and the OpenSearch Dashboards endpoint.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#collection_endpointString

Collection-specific endpoint used to submit index, search, and data upload requests to an OpenSearch Serverless collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateInteger

The Epoch time when the collection was created.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#dashboard_endpointString

Collection-specific endpoint used to access OpenSearch Dashboards.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#idString

A unique identifier for the collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_arnString

The ARN of the Amazon Web Services KMS key used to encrypt the collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#last_modified_dateInteger

The date and time when the collection was last modified.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#standby_replicasString

Details about an OpenSearch Serverless collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of collection.



345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 345

class CollectionDetail < Struct.new(
  :arn,
  :collection_endpoint,
  :created_date,
  :dashboard_endpoint,
  :description,
  :id,
  :kms_key_arn,
  :last_modified_date,
  :name,
  :standby_replicas,
  :status,
  :type)
  SENSITIVE = []
  include Aws::Structure
end