Class: Aws::OpenSearchServerless::Types::CreateCollectionDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::CreateCollectionDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Details about the created OpenSearch Serverless collection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the collection.
-
#collection_group_name ⇒ String
The name of the collection group that contains this collection.
-
#created_date ⇒ Integer
The Epoch time when the collection was created.
-
#deletion_protection ⇒ String
Indicates whether deletion protection is ‘ENABLED` or `DISABLED` for the collection.
-
#description ⇒ String
A description of the collection.
-
#id ⇒ String
The unique identifier of the collection.
-
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key with which to encrypt the collection.
-
#last_modified_date ⇒ Integer
The date and time when the collection was last modified.
-
#name ⇒ String
The name of the collection.
-
#standby_replicas ⇒ String
Creates details about an OpenSearch Serverless collection.
-
#status ⇒ String
The current status of the collection.
-
#type ⇒ String
The type of collection.
-
#vector_options ⇒ Types::VectorOptions
Configuration options for vector search capabilities in the collection.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#collection_group_name ⇒ String
The name of the collection group that contains this collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#created_date ⇒ Integer
The Epoch time when the collection was created.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ String
Indicates whether deletion protection is ‘ENABLED` or `DISABLED` for the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#id ⇒ String
The unique identifier of the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#kms_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key with which to encrypt the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#last_modified_date ⇒ Integer
The date and time when the collection was last modified.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#standby_replicas ⇒ String
Creates details about an OpenSearch Serverless collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |
#vector_options ⇒ Types::VectorOptions
Configuration options for vector search capabilities in the collection.
852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 852 class CreateCollectionDetail < Struct.new( :id, :name, :status, :type, :description, :arn, :kms_key_arn, :standby_replicas, :deletion_protection, :vector_options, :created_date, :last_modified_date, :collection_group_name) SENSITIVE = [] include Aws::Structure end |