Class: Aws::OpenSearchServerless::Types::CreateVpcEndpointRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-opensearchserverless/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

Unique, case-sensitive identifier to ensure idempotency of the request.

**A suitable default value is auto-generated.** You should normally not need to pass this option.



837
838
839
840
841
842
843
844
845
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 837

class CreateVpcEndpointRequest < Struct.new(
  :client_token,
  :name,
  :security_group_ids,
  :subnet_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the interface endpoint.



837
838
839
840
841
842
843
844
845
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 837

class CreateVpcEndpointRequest < Struct.new(
  :client_token,
  :name,
  :security_group_ids,
  :subnet_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#security_group_idsArray<String>

The unique identifiers of the security groups that define the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.



837
838
839
840
841
842
843
844
845
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 837

class CreateVpcEndpointRequest < Struct.new(
  :client_token,
  :name,
  :security_group_ids,
  :subnet_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_idsArray<String>

The ID of one or more subnets from which you’ll access OpenSearch Serverless.



837
838
839
840
841
842
843
844
845
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 837

class CreateVpcEndpointRequest < Struct.new(
  :client_token,
  :name,
  :security_group_ids,
  :subnet_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The ID of the VPC from which you’ll access OpenSearch Serverless.



837
838
839
840
841
842
843
844
845
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 837

class CreateVpcEndpointRequest < Struct.new(
  :client_token,
  :name,
  :security_group_ids,
  :subnet_ids,
  :vpc_id)
  SENSITIVE = []
  include Aws::Structure
end