Class: Aws::OpenSearchServerless::Types::ListSecurityConfigsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::ListSecurityConfigsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListSecurityConfigsoperation returns anextToken, you can include the returnednextTokenin subsequentListSecurityConfigsoperations, which returns results in the next page. -
#type ⇒ String
The type of security configuration.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to get the next page of results.
The default is 20.
2430 2431 2432 2433 2434 2435 2436 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2430 class ListSecurityConfigsRequest < Struct.new( :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListSecurityConfigs operation returns a
nextToken, you can include the returned nextToken in subsequent
ListSecurityConfigs operations, which returns results in the next
page.
2430 2431 2432 2433 2434 2435 2436 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2430 class ListSecurityConfigsRequest < Struct.new( :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of security configuration.
2430 2431 2432 2433 2434 2435 2436 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2430 class ListSecurityConfigsRequest < Struct.new( :type, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |