Class: Aws::OpenSearchServerless::Types::ListVpcEndpointsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::OpenSearchServerless::Types::ListVpcEndpointsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-opensearchserverless/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results to return.
-
#next_token ⇒ String
If your initial
ListVpcEndpointsoperation returns anextToken, you can include the returnednextTokenin subsequentListVpcEndpointsoperations, which returns results in the next page. -
#vpc_endpoint_filters ⇒ Types::VpcEndpointFilters
Filter the results according to the current status of the VPC endpoint.
Instance Attribute Details
#max_results ⇒ Integer
An optional parameter that specifies the maximum number of results
to return. You can use nextToken to get the next page of results.
The default is 20.
2558 2559 2560 2561 2562 2563 2564 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2558 class ListVpcEndpointsRequest < Struct.new( :vpc_endpoint_filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If your initial ListVpcEndpoints operation returns a nextToken,
you can include the returned nextToken in subsequent
ListVpcEndpoints operations, which returns results in the next
page.
2558 2559 2560 2561 2562 2563 2564 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2558 class ListVpcEndpointsRequest < Struct.new( :vpc_endpoint_filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |
#vpc_endpoint_filters ⇒ Types::VpcEndpointFilters
Filter the results according to the current status of the VPC
endpoint. Possible statuses are CREATING, DELETING, UPDATING,
ACTIVE, and FAILED.
2558 2559 2560 2561 2562 2563 2564 |
# File 'lib/aws-sdk-opensearchserverless/types.rb', line 2558 class ListVpcEndpointsRequest < Struct.new( :vpc_endpoint_filters, :next_token, :max_results) SENSITIVE = [] include Aws::Structure end |